@@ -1,6 +1,18 @@
 from collections import namedtuple
+from copy import deepcopy
+from datetime import date, datetime, timezone
 from enum import IntEnum
-from typing import Any, Union
+from typing import Any, Optional, Union
+
+try:
+    from zoneinfo import ZoneInfo  # type: ignore
+except ImportError:
+    from backports.zoneinfo import ZoneInfo  # type: ignore
+
+from backports.datetime_fromisoformat import MonkeyPatch  # type: ignore
+
+# Remove when we drop python 3.6 support
+MonkeyPatch.patch_fromisoformat()
 
 
 class VisState(IntEnum):
@@ -31,18 +43,48 @@ class Result:
     ```
     """
 
-    def __init__(self, name: str, data: dict):
-        self.name = name
+    def __init__(self, name: Optional[str], data: dict):
+        self._name = name
         self.data = data.get(name, {})
 
     def __str__(self) -> str:
-        return "Result({})".format(self.name)
+        return "Result({})".format(self._name)
 
     def __repr__(self) -> str:  # pragma: no cover
-        return "Result({})".format(self.name)
+        return "Result({})".format(self._name)
 
     def __getattr__(self, field: str) -> Any:
-        return self.data.get(field)
+        field_data = self.data.get(field)
+        if isinstance(field_data, dict):
+            return Result(field, {field: field_data})
+        if isinstance(field_data, list):
+            return ListResult(field, field, {field: field_data}, include_pages=False)
+        if isinstance(field_data, str):
+            # Check if the String is a date
+            try:
+                return date.fromisoformat(field_data)  # type: ignore
+            except ValueError:
+                pass
+
+            # Check if the String is a datetime
+            try:
+                # This logic pains me, but datetimes in FreshBooks:
+                # - Project-like resources return dates in UTC.
+                #   Most use proper ISO 8601 format, but many omit the UTC time zone
+                #   designator ("Z") at the end (but are still UTC). Python `fromisoformat`
+                #   doesn't like the "Z", so we strip it.
+                # - Accounting resources return dates in "US/Eastern",
+                #   except the client signup date, which is UTC.
+                #   These dates are in the format "yyyy-MM-dd HH:mm:ss",
+                #   so we can distinguish them with the absent "T".
+                parsed_date = datetime.fromisoformat(field_data.rstrip("Z"))  # type: ignore
+                if "T" in field_data or (self._name == "client" and field == "signup_date"):
+                    return parsed_date.replace(tzinfo=timezone.utc)
+                return parsed_date.replace(tzinfo=ZoneInfo("US/Eastern")).astimezone(timezone.utc)
+            except ValueError:
+                return field_data
+
+        return field_data
 
     @property
     def vis_state(self) -> Union[VisState, None]:
@@ -89,33 +131,49 @@ class ListResult:
     For including pagination in requests, see `freshbooks.builders.paginator.PaginateBuilder`.
     """
 
-    def __init__(self, name: str, single_name: str, data: dict):
-        self.name = name
-        self.single_name = single_name
+    def __init__(self, name: str, single_name: str, data: dict, include_pages: bool = True):
+        self._name = name
+        self._single_name = single_name
         self.data = data
-        self.pages = self._constructPages(data)
+        if include_pages:
+            self.pages = self._constructPages(data)
 
     def __str__(self) -> str:
-        return "Result({})".format(self.name)
+        return "ListResult({})".format(self._name)
 
     def __repr__(self) -> str:  # pragma: no cover
-        return "Result({})".format(self.name)
+        return "ListResult({})".format(self._name)
+
+    def __add__(self, other: "ListResult") -> "ListResult":
+        if not isinstance(other, ListResult) or (self._name != other._name):
+            raise TypeError("Objects not of same ListResult type")
+
+        data = deepcopy(self.data)
+        data.get(self._name, []).extend(other.data.get(self._name))
+        new_result = ListResult(self._name, self._single_name, data, include_pages=False)
+
+        if other.pages and other.pages.page > self.pages.page:
+            new_result.pages = new_result._constructPages(other.data)
+        elif self.pages:  # pragma: no branch
+            new_result.pages = new_result._constructPages(self.data)
+
+        return new_result
 
     def __len__(self) -> int:
-        return len(self.data.get(self.name, []))
+        return len(self.data.get(self._name, []))
 
     def __getitem__(self, index: int) -> Result:
-        results = self.data.get(self.name, [])
-        return Result(self.single_name, {self.single_name: results[index]})
+        results = self.data.get(self._name, [])
+        return Result(self._single_name, {self._single_name: results[index]})
 
     def __iter__(self) -> Any:
         self.n = 0
         return self
 
     def __next__(self) -> Result:
-        results = self.data.get(self.name, [])
+        results = self.data.get(self._name, [])
         if self.n < len(results):
-            result = Result(self.single_name, {self.single_name: results[self.n]})
+            result = Result(self._single_name, {self._single_name: results[self.n]})
             self.n += 1
             return result
         else:
@@ -138,7 +196,7 @@ class Identity(Result):
 
     Example:
     ```python
-    >>> current_user = freshBooksClient.current_user
+    >>> current_user = freshBooksClient.current_user()
     >>> current_user.email
     <some email>
 
